<template>
  <basic-container>
    <avue-crud ref="crud"
               v-model="form"
               :data="data"
               :option="option"
               :page.sync="page"
               :table-loading="loading"
               @row-del="rowDel"
               @row-update="rowUpdate"
               @row-save="rowSave"
               @selection-change="selectionChange"
               @current-change="currentChange"
               @size-change="sizeChange"
               @refresh-change="refreshChange"
               @on-load="onLoad">
      <template slot="menuLeft" slot-scope="scope">
        <el-button icon="el-icon-search"
                   plain
                   size="small"
                   type="primary" @click="searchHandler">查 询
        </el-button>
        <advanced-query :options="options" :visible.sync="findvisible"
                        @echoContion="echoContion"></advanced-query>
        <el-button icon="el-icon-delete"
                   plain
                   size="small"
                   type="danger" @click="deleteHandler">删 除
        </el-button>
        <el-button icon="el-icon-edit"
                   plain
                   size="small"
                   type="success" @click="editHandler">修 改
        </el-button>
        <el-button icon="el-icon-refresh-right"
                   plain
                   size="small"
                   type="primary" @click="onLoad">刷 新
        </el-button>
      </template>
    </avue-crud>
  </basic-container>
</template>

<script>
import {getList, add, editSave, deleteData} from "@/api/code/codeMatch";

export default {
  name: "Match",
  data() {
    return {
      options: [
        {
          fieid: 'id',
          title: '编号',
          fieldType: 'text',
          queryField: 'id'
        },
        {
          fieid: 'name',
          title: '名称',
          fieldType: 'text',
          queryField: 'name'
        },
        {
          fieid: 'ignoreallspaceflag',
          title: '忽略全部空格',
          fieldType: 'truefalse',
          queryField: 'ignoreallspaceflag'
        },
        {
          fieid: 'ignorecaseflag',
          title: '忽略大小写',
          fieldType: 'truefalse',
          queryField: 'ignorecaseflag'
        },
        {
          fieid: 'ignorespaceflag',
          title: '忽略空格',
          fieldType: 'truefalse',
          queryField: 'ignorespaceflag'
        },
        {
          fieid: 'ignorewidthflag',
          title: '忽略全半角',
          fieldType: 'truefalse',
          queryField: 'ignorewidthflag'
        },
        {
          fieid: 'linkCharacter',
          title: '忽略连接字符',
          fieldType: 'text',
          queryField: 'linkCharacter'
        },
      ],
      findvisible: false,
      selectRow: [],
      option: {
        height: 700,
        calcHeight: 80,
        tip: false,
        searchShow: true,
        searchMenuSpan: 6,
        columnBtn: false,
        border: true,
        index: true,
        selection: true,
        dialogClickModal: false,
        highlightCurrentRow: true,
        column: [
          {
            label: "编号",
            prop: "id",
            labelWidth: 100,
            rules: [{
              required: true,
              message: "请输入编号",
              trigger: "blur"
            }]
          },
          {
            label: "名称",
            prop: "name",
            rules: [{
              required: true,
              message: "请输入名称",
              trigger: "blur"
            }]
          },
          {
            label: "忽略全部空格",
            prop: "ignoreallspaceflag",
            labelWidth: 100,
            type: 'switch',
            dicData: [{
              label: '否',
              value: 'false'
            }, {
              label: '是',
              value: 'true'
            }],
            formatter: function (row) {
              return row.ignoreallspaceflag === 'true' ? '是' : '否'
            }
          },
          {
            label: "忽略大小写",
            prop: "ignorecaseflag",
            type: 'switch',
            dicData: [{
              label: '否',
              value: 'false'
            }, {
              label: '是',
              value: 'true'
            }],
            formatter: function (row) {
              return row.ignorecaseflag === 'true' ? '是' : '否'
            }
          },
          {
            label: "忽略空格",
            prop: "ignorespaceflag",
            type: 'switch',
            labelWidth: 100,
            dicData: [{
              label: '否',
              value: 'false'
            }, {
              label: '是',
              value: 'true'
            }],
            formatter: function (row) {
              return row.ignorespaceflag === 'true' ? '是' : '否'
            }
          },
          {
            label: "忽略全半角",
            prop: "ignorewidthflag",
            type: 'switch',
            dicData: [{
              label: '否',
              value: 'false'
            }, {
              label: '是',
              value: 'true'
            }],
            formatter: function (row) {
              return row.ignorewidthflag === 'true' ? '是' : '否'
            }
          },
          {
            label: "忽略连接字符",
            prop: "linkCharacter",
            type: 'textarea',
            labelWidth: 100,
            span: 24

          }
        ]
      },
      loading: true,
      data: [],
      form: {},
      page: {
        pageSize: 10,
        currentPage: 1,
        total: 0
      },
    }
  },
  created() {
    this.onLoad()
  },
  methods: {
    searchHandler() {
      this.findvisible = true;
    },
    echoContion(val) {
      console.log(...val)
      // FindData({
      //   templateOid: this.templateOid,
      //   codeClassifyOid: this.codeClassifyOid,
      //   ...val,
      // }).then((res) => {
      //   this.tableData = res.data.data;
      //   this.page.total = res.data.total
      // });
    },
    deleteHandler() {
      const length = this.selectRow.length;
      if (length > 1) {
        this.$message.warning('只能选择一条数据！');
        return;
      }
      if (length <= 0) {
        this.$message.warning('请选择一条数据! ');
        return;
      }
      this.$confirm("确定将选择数据删除?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return deleteData(this.selectRow[0])
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
        });

    },
    editHandler() {
      const length = this.selectRow.length;
      if (length > 1) {
        this.$message.warning('只能选择一条数据！');
        return;
      }
      if (length <= 0) {
        this.$message.warning('请选择一条数据! ');
        return;
      }
      this.$refs.crud.rowEdit(this.selectRow[0]);
    },
    rowDel(row) {
      this.$confirm("确定将选择数据删除?", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      })
        .then(() => {
          return deleteData(row);
        })
        .then(() => {
          this.onLoad(this.page);
          this.$message({
            type: "success",
            message: "操作成功!"
          });
        });
    },
    rowUpdate(row, index, done, loading) {
      console.log(row)
      editSave(row).then(() => {
        this.onLoad(this.page);
        this.$message({
          type: "success",
          message: "操作成功!"
        });
        done();
      }, error => {
        loading();
        console.log(error);
      });
    },
    rowSave(row, done, loading) {
      add(row).then(() => {
        this.onLoad(this.page);
        this.$message({
          type: "success",
          message: "操作成功!"
        });
        done();
      }, error => {
        window.console.log(error);
        loading();
      });
    },
    selectionChange(row) {
      // console.log(row)
      this.selectRow = row;
    },
    currentChange(currentPage) {
      this.page.currentPage = currentPage;
    },
    sizeChange(pageSize) {
      this.page.pageSize = pageSize;
    },
    refreshChange() {
      this.onLoad(this.page.currentPage, this.page.pageSize);
    },
    onLoad(page) {
      this.loading = true;
      getList(this.page.currentPage, this.page.pageSize).then(res => {
        if (res.data && res.data.data.length > 0) {
          this.page.total = res.data.total;
          this.data = res.data.data;
        }
        this.loading = false;
      });
    }
  }
}
</script>

<style scoped>

</style>
